//=========================================================================//
// DROPSTTC.CPP : C++ source code for the drop boxes in the main window    //
//                dialog of the Port Status & Setup program.               //
// Remarks      : Compiled under the large memory model.                   //
// History      : 05/28/95 Original version                                //
//                                                                         //
// Written By   : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ     // 
//=========================================================================//


#include "dropsttc.h"     //Header containing this source file's declarations
#include "portsetc.rh"    //Header containing resource identifiers
#include "portsetc.h"     //This module's header for type definitions


//========================================================================//
// CDropStatic - Derived from CStatic, this class is used to allow for 
//               the dropping of MA+ Line or Group service names on to the 
//               Virtual Comm Port Assignments static window elements
//========================================================================//
CDropStatic::CDropStatic(UINT idStatic, CWnd* parent)     //Class constructor
{
   //
   //Attach this class to the static resource template which already
   //has been created in the PORTSET.RC file
   //
   SubclassDlgItem(idStatic, parent);

   //-----------------------------------------------------------------//
   // Below we set a smaller font for the list box windows
   //-----------------------------------------------------------------//
       
   //  
   //First get the current font
   //
   CFont* TheOldFont = GetFont();
       
   //
   //Copy its LOGFONT structure to a variable we can use
   //
   LOGFONT logFont;
   TheOldFont->GetObject( sizeof( LOGFONT ), &logFont );
 
   //
   //Change the weight in the LOGFONT structure
   //
   logFont.lfWeight = FW_MEDIUM;
    
   //
   //Create a new font based on the modified LOGFONT structure
   //
   NewFont = new CFont();
   NewFont->CreateFontIndirect( &logFont ); 

   //
   //Set the new font of the list box windows
   //
   SetFont(NewFont, FALSE);
       
   //
   //Indicate its text has not yet changed
   //
   HasChanged = FALSE;
}  //End CDropStatic::CDropStatic

  
//------------------------------------------------------------------------//
// CDropStatic::PostNcDestroy
// 
// Parameters     None
// Returns        Nothing
// Called By      Windows framework when the Window is destroyed
// Remarks        Destructor for the class to delete the NewFont pointer
//------------------------------------------------------------------------//
void CDropStatic::PostNcDestroy()
{
   CStatic::PostNcDestroy();   //Call the base class function
   NewFont->DeleteObject ();   //Delete the GDI object attached to font
   delete NewFont;             //Delete the NewFont object from the heap
   delete this;                //Delete this object from the heap
}  //End CDropStatic::PostNcDestroy
   

