//------------------------------------------------------------------------//
// MAINDLG.H   Header file for MAINDLG.CPP
//------------------------------------------------------------------------//
//
//If MAINDLG.H has not already been included in the compile, then,
//                                                                
#ifndef __MAINDLG_H

//
//Define the inclusion of MAINDLG.H and make all the definitions following
//below in this file
//
#define __MAINDLG_H

#include <afxwin.h>        //MFC header file - all MFC apps must use
#include "aboutdlg.h"      //Header containing About dialog declarations
#include "massist.h"       //Header for the MASSIST.CPP source module  
#include "mdetail.h"       //Header for the MDETAIL.CPP source module
#include "lservers.h"      //Header for the LSERVERS.CPP source module
#include "draglist.h"      //Header for the DRAGLIST.CPP source module
#include "dropsttc.h"      //Header for the DROPSTTC.CPP source module  


//========================================================================//
// CMainDialog client window class.  This class will be used to construct
// and manipulate the main dialog for the PORTSET.EXE application.                               
//========================================================================//

class CMainDialog : public CDialog
{
public:
  CMainDialog ();                   // constructor for this class
  BOOL OnInitDialog();              // overridden dialog initialize function
  BOOL GetMAValues ();              // calls MA+ drivers & reads parameters
  afx_msg void OnSysColorChange (); // overridden system color change fn
  afx_msg void OnWindowPosChanged   // overidden window move function
               (WINDOWPOS FAR* lpwndpos); 
          void OnOK ();             // dialog window OK function
          void OnCancel ();         // dialog window cancel function
  afx_msg void OnClose ();
  afx_msg void OnExitClick ();      // dialog window close function
  afx_msg void OnDestroy ();        // overridden dialog window destroy fn
  //afx_msg void OnNcDestroy ();
  afx_msg void OnRefresh ();        // refresh service names function
  afx_msg void OnSave();            // save port assignments to MCLIENT.INI
  afx_msg void OnListServers ();    // show dialog with Server name list
  afx_msg void OnMoreDetail ();     // show dialog with More Detail info
  afx_msg void OnUsage ();          // bring up the MA+ Online Help
  afx_msg void OnAbout ();          // show About dialog for this applicaton
  afx_msg void OnInstallMACOMM ();  // put MACOMM.DRV in SYSTEM.INI
   
  BOOL GetNamesDLL ();         // calls CMApiCall with AH=10h in MCLIENT.DLL
                               // to retrieve MA+ service names  
  BOOL GetNamesTSR ();   // calls RMCall function in PORTSET.DLL which calls
                               // calls function Query Service Names (AH=10h)
                               // in MCLIENT.EXE through DPMI
  BOOL LoadMClientDLL();                  // loads MCLIENT.DLL
  void AddLineAndStatus(char* szstring);      // appends Status char string
                                  // to Line Name char string    
  void PrepareRMCS(RCALLSTRUCT* pRCallStruct, // Initializes some members
                   int Subfunction);          // of RCallStruct before 
                               // calling CMApiCall function
  void TSRLabel();    //Changes dialog's "Client in Use" label to TSR
  void LinesLabel();    //Assigns appropriate info to "Lines Found" label
  void ServersLabel();     //Displays appropriate label for Active Servers
   
  int  ReadMClientINI();  //Reads virtual comm port assignments from the
                          //MCLIENT.INI file and sets appropriate textlabels
  void CreateLists();      //Creates the Available Lines and Groups lists              
  
  //
  //OnLButtonDblClk response function
  //to reset port assignment to 'Local'
  //
  afx_msg void OnLButtonDblClk(UINT nFlags,
                               CPoint point); 
  afx_msg void OnMouseMove(UINT nFlags,
                           CPoint point); //message response function
  
  //
  //OnCtlColor is used to color the groupboxes red text
  //
  afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
  
  //
  //GetComAssignRects fills CRect structures with the window rectangle
  //dimensions of 2 static controls. These controls are associated the with
  //the Windows comm port as indexed in the parameter ComIndex
  //
  void GetComAssignRects(int ComIndex, CRect &LeftRect, CRect &RightRect); 

  //
  //SetComAssign sets the window text of the static control as indexed 
  //
  void SetComAssign(int ComIndex, const char* Assignment);
  
  //
  //Saves modified Windows comm port assignments to MCLIENT.INI
  //
  void SaveSettings();

  //
  //Asks the user "Save settings before exit? Yes,No,Cancel"
  //
  BOOL QuerySaveAndExit();

  void PostNcDestroy();         //Deletes the C++ object
  void SetStatusBarText (int nID); //changes current status bar text
  void InitStatusBar ();           //Initialized the status bar window
  void CheckForMACOMMDRV ();       //Check that MACOMM.DRV is in SYSTEM.INI

private:
  int HeightStatusBarFont;      //Font handle for the status bar
  CBrush BackgroundBrush;       //Brush for the dialog's background

  CLineInfo LineInfo;           //Holds MA+ service info
  CListServers ListServersDlg;  //Class to reference List Servers dialog
  CMoreDetail MoreDetailDlg;    //Class to reference More Detail dialog

  CDragList* Lines ;            //Pointer to the Available Lines list box
  CDragList* Groups;            //Pointer to the Available Groups list box

  CDropStatic* ComAssign[9];    //Array of pointers to the Comm Assignments
                                //labels
  CBitmapButton Buttons[5];     //Array for manipulating dialog buttons 
  int NumLines;                 //Number of MA+ Lines retrieved
  BOOL ComAssignsChanged;       //Flag indicating Windows comm port assign-
                                //ments have been modified and need saving  
  CRect LinesRect,              //Dimensions for the available lines list
        GroupsRect,             //Dimensions for the available groups list
        PortsRect,              //Dimensions for the virtual com ports box
        ActiveServersRect,      //Dimensions for active servers status area 
        ActiveLinesRect,        //Dimensions for active lines status area 
        ClientInUseRect;        //Dimensions for client in use status area 

  CString PresentCommDriver;    //Path and file name of current comm driver
                                
DECLARE_MESSAGE_MAP ()          //Response map to Windows messages
};                                                                           

//
//End of preprocessor directive to include MAINDLG.H
//
#endif 
