//========================================================================//
// MDETAIL.CPP : C++ source code for the More Detail dialog of the Port   //
//               Status & Setup program.  See PORTSETC.DEF for more info. //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "mdetail.h"            //Header for this source file
#include "portsetc.rh"          //Header containing resource identifiers
#include "ctl3d.h"              //Header for 3D controls library 


//========================================================================//
// Global variable and function declarations
//========================================================================//

extern char __far lpszMCIniPath[60];  //File path to MCLIENT.INI file
extern char __far ClientConValues[51];//Buffer containing CLIENT.CON values 
extern BOOL TSRLoaded;                //Flag indicating MCLIENT.EXE is loaded
                                   

//========================================================================//
// CMoreDetail class - This class is used to reference the More Detail
//                   dialog element. The dialog has a sequence of labels
//                   each providing particular MA+ configuration info.
//========================================================================//

BEGIN_MESSAGE_MAP(CMoreDetail, CDialog)
   ON_COMMAND(IDOK, OnOK)
   ON_COMMAND(IDCANCEL, OnOK) 
END_MESSAGE_MAP()

//------------------------------------------------------------------------//
// CMoreDetail() - Constructor for the CMoreDetail class.
//------------------------------------------------------------------------//
CMoreDetail::CMoreDetail ()
{

   Create(MOREDETAILDLG);                     //Create the dialog element

   //---------------------------------------------------------------------//
   // Below we centre the dialog on the main dialog...
   //---------------------------------------------------------------------//        
   
   RECT r1;                        //Holds the dialog window dimensions
   int left, top, width, height;   //Variables for moving the window
              
   GetWindowRect(&r1);             //Get the window dimensions
   width = r1.right - r1.left;     //Find the width
   height = r1.bottom - r1.top;    //Find the height
   left = (GetSystemMetrics(SM_CXSCREEN) - width) / 2; //Centre on    
   top = (GetSystemMetrics(SM_CYSCREEN) - height) / 2; //screen
              
   MoveWindow(left, top, width, height, FALSE);        //Place the window

}
  

//------------------------------------------------------------------------//
// CMoreDetail::OnInitDialog
// 
// Parameters     None
// Returns        Boolean. True if focus for a child window was set.
// Called by      Windows mechanism before CMoreDetail::Create (apparently)
// Remarks        Used to indicate which child controls will be 3D
//------------------------------------------------------------------------//
BOOL CMoreDetail::OnInitDialog() 
{
   //
   //Call the ancestor function
   //
   CDialog::OnInitDialog();

   //
   //Indicate frames are 3D
   //
   Ctl3dSubclassDlg(m_hWnd, CTL3D_STATICFRAMES);                          

   //
   //Load bitmaps for bitmap button (does SubclassButton also)
   //
   OkButton.AutoLoad(IDOK, this);
   
   return TRUE;
}
 
 
//------------------------------------------------------------------------//
// CMoreDetail() - Assigns the labels' character strings.
//------------------------------------------------------------------------//
void CMoreDetail::SetLabels ()
{
   CStatic* Label;
   char szIniBuffer[60];    //Character string to hold RedirectPorts stmt
   
   //
   //If MCLIENT.EXE is load in memory, then..
   //
   if (TSRLoaded == TRUE)                    
      {
       //
       //MClient in Use label is set to "TSR". Otherwise the default is "DLL"
       //
       Label = (CStatic*) GetDlgItem(LBL_MCLIENTINUSE);
       Label->SetWindowText("TSR");
       
       //
       //NASI and INT14 label is set to "Available. Otherwise default
       //is "Unavailable" 
       //
       Label = (CStatic*) GetDlgItem(LBL_NASIINT14);
       Label->SetWindowText("Available");
      }
   
   //
   //Get the RedirectPorts statement from MCLIENT.INI
   //
   GetPrivateProfileString("Redirector",    //[Redirector] section
                           "RedirectPorts", //"RedirectPorts" statement
                           "None",          //default return value
                           szIniBuffer,     //Character string buffer
                           60,              //Size of buffer
                           lpszMCIniPath);  // [path]MClient.INI
   //
   //Put the character string in the appropriate dialog label
   //
   Label = (CStatic*) GetDlgItem(LBL_REDIRECTED);
   Label->SetWindowText(szIniBuffer);  
   
   //
   //Get the MCLIENT.DLL path from the ClientDLL statement in MCLIENT.INI
   //
   GetPrivateProfileString("Redirector",     //[Redirector] section
                           "ClientDLL",      //"ClientDLL" statement
                           "Not Specified",  //Default
                           szIniBuffer,      //Character string buffer
                           60,               //Size of buffer
                           lpszMCIniPath);   // [path]MClient.INI      
   //
   //Put the character string in the appropriate dialog label
   //
   Label = (CStatic*) GetDlgItem(LBL_DLLPATH);
   Label->SetWindowText(szIniBuffer);  
   
   //
   //Get the FileName statement from MCLIENT.INI
   //
   GetPrivateProfileString("ClientParms",    //[ClientParms] section
                           "FileName",       //"FileName" statement
                           "Not Specified",  //default return value
                           szIniBuffer,      //Character string buffer
                           60,               //Size of buffer
                           lpszMCIniPath);   // [path]MClient.INI
   //
   //Put the character string in the appropriate dialog label
   //
   Label = (CStatic*) GetDlgItem(LBL_CONPATH);
   Label->SetWindowText(szIniBuffer);  
  
   //
   //For each remaining More Detail label, we set the text according
   //to the appropriate value in the CLIENT.CON file
   //
   Label = (CStatic*) GetDlgItem(LBL_QUEUE);
   Label->SetWindowText(ClientConValues + 13);    
        
   Label = (CStatic*) GetDlgItem(LBL_RETRY);
   Label->SetWindowText(ClientConValues + 15);    
   
   Label = (CStatic*) GetDlgItem(LBL_NASILEVEL);
   Label->SetWindowText(ClientConValues + 11);    
   
   Label = (CStatic*) GetDlgItem(LBL_TIMEOUT);
   Label->SetWindowText(ClientConValues + 7);    
   
   Label = (CStatic*) GetDlgItem(LBL_BUFFERSIZE);
   Label->SetWindowText(ClientConValues);    
   
   Label = (CStatic*) GetDlgItem(LBL_CONNECTDEST);
   Label->SetWindowText(ClientConValues + 34);    
   
   Label = (CStatic*) GetDlgItem(LBL_SERVICENAME);
   Label->SetWindowText(ClientConValues + 17);    
   
   Label = (CStatic*) GetDlgItem(LBL_INIPATH);//Assign pointer to label
   Label->SetWindowText(lpszMCIniPath);       //Assign label text

}



//------------------------------------------------------------------------//
// CMoreDetail::OnOK
//
// Parameters     None
//
// Returns        Nothing
//
// Called by      Windows mechanism when the dialog receives the 
//                WM_OK message
//                                
// Remarks        Overridden ancestor function used to re enable the main
//                dialog after this window closes
//------------------------------------------------------------------------//
afx_msg void CMoreDetail::OnOK()
{
   CDialog* pMainDlg;       //Pointer to the main dialog 
   pMainDlg = (CDialog*) AfxGetMainWnd();//Assign pointer to main dialog

   //
   //Re enable the main dialog
   //
   pMainDlg->EnableWindow(TRUE);
   
   //
   //Re activate the main dialog
   //
   pMainDlg->SetFocus();

   //
   //Call ancestor function. This calls EndDialog which will hide the 
   //dialog window. We may want to use this dialog again so we do this
   //instead of overriding OnOK and calling DestroyWindow.
   //
   //DestroyWindow is called in CMainDialog::OnCloseClick
   //
   CDialog::OnOK();
}
 
 
