//========================================================================//
// PORTSETC.CPP: C++ source code for the Port Status & Setup program.     //
//                                                                        //
// Remarks     : Compiled under the large memory model with links to      //
//               PORTSET.DLL. See PORTSETC.DEF for more information.      //
//                                                                        //
// History     : 05/01/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "portsetc.h"      //This module's header for type definitions
#include "maindlg.h"       //Header for the MAINDLG.CPP source module
#include "ctl3d.h"         //3D control header file for linking ctl3ds.lib
#include "messages.h"      //Header containing all string constants
#include "portsetc.rh"     //Header containing resource identifiers


//========================================================================//
// Global variables and functions...                                      //
//========================================================================//

HINSTANCE   hinstMClient = NULL; //handle to MCLIENT.DLL
BOOL        TSRLoaded = FALSE;   //flag indicating that MCLIENT.EXE is loaded
HWND        ghDlg;               //handle to the main dialog
HACCEL      ghAccelTable;        //handle to the accelerator table
char __far  lpszMCIniPath[60];   //File path to MCLIENT.INI file   
char __far  lpszMCDLLPath[60];   //File path to MCLIENT.DLL 
char __far  ClientConValues[51]; //Buffer containing CLIENT.CON values 


//========================================================================//
// CApp class:                                       
//========================================================================//

//------------------------------------------------------------------------//
// InitApplication - Checks that we are in enhanced mode, and then 
//                   MCLIENT.INI
//------------------------------------------------------------------------//
BOOL CApp::InitApplication()
{

   if (!(GetWinFlags() & WF_ENHANCED))      //If standard mode..
      {      
      ::MessageBox(NULL, ONLY_ENHANCED_MODE,APP_TITLE, MB_ICONSTOP);//Message
      return FALSE;                         //Abort application
      }
   
   if (!MClientINIExists()) return FALSE; //Abort if we can't find MCLIENT.INI

   //
   //Load the icon to use for this application's main window
   //
   PortSetIcon = LoadIcon (AFX_IDI_STD_FRAME);

   return TRUE;      
}               


//------------------------------------------------------------------------//
// InitInstance - Although this program is large memory model and hence, 
//              single instance, we override this function to invoke
//              3D controls, load the accelerator keys table,
//              and assign the main dialog window.
//------------------------------------------------------------------------//
BOOL CApp::InitInstance()
{
   DoWaitCursor(1);                //Display wait cursor and initial message
   
   //
   //Show the initial non-user-controllable message window
   //
   MakeSplash();

   //
   //Register app as 3D client
   //
   Ctl3dRegister(m_hInstance);             
   
   //
   //AutoSubclassing for 3D controls appeared to suck away my overridden
   //CMainDialog::OnCtlColor() function, so I couldn't have red text 
   //for the frame boxes (which are actually "button" elements).
   //So I disabled the call to Ctl3dAutoSubclass() above and set the 
   //background of my dialog by calling SetDialogBkColor using a 
   //system color.
   //
   SetDialogBkColor (::GetSysColor (COLOR_BTNFACE)); 

   ghAccelTable = LoadAccelerators(m_hInstance,  //Load accelerator table
                                   MAKEINTRESOURCE(MAIN_ACCEL));

   m_pMainWnd = new CMainDialog ();     //Assign main window
   m_pMainWnd->ShowWindow (m_nCmdShow); //Show main window
   DoWaitCursor (0);                    //Show arrow cursor again
   return TRUE;                                 
}


//------------------------------------------------------------------------//
// CApp::MakeSplash
// 
// Parameters     None
// Returns        Nothing
// Called By      CApp::InitInstance
// Remarks        This function displays the application's initial splash
//                window "Scanning Network for Communications Servers.."
//------------------------------------------------------------------------//
void CApp::MakeSplash()
{
   //
   //Create the splash window
   //
   SplashWindow = new CMessageWnd();
   
}


//------------------------------------------------------------------------//
// ProcessMessageFilter - overrides same function in CWinApp class. Assigns
//                     an accelerator resource to the dialog menu.
//------------------------------------------------------------------------//
BOOL CApp::ProcessMessageFilter(int code, LPMSG lpMsg)
{
   if (code < 0) CWinApp::ProcessMessageFilter(code, lpMsg);
       
   if (ghDlg && ghAccelTable) 
      {
       if (::TranslateAccelerator(ghDlg, ghAccelTable, lpMsg))
                     return TRUE;
      }
       
   return CWinApp::ProcessMessageFilter(code, lpMsg);          
}
              

//------------------------------------------------------------------------//
// DoWaitCursor - overridden function to display the initial message 
//                and the wait cursor
//------------------------------------------------------------------------//
void CApp::DoWaitCursor(int nCode)
{
   CWinApp::DoWaitCursor(nCode);
}


//------------------------------------------------------------------------//
// MClientINIExists - Determines the path to the file MCLIENT.INI
//------------------------------------------------------------------------//
BOOL CApp::MClientINIExists()
{
   int xvalue;                     //General purpose function return value
   char szMessage[100], szErrorCode[6]; //General purpose character arrays
   OFSTRUCT FAR* lpOpenBuffer;            //Structure to hold file information
   
   lpOpenBuffer = new OFSTRUCT;         //Allocate the file info buffer
   
   xvalue = OpenFile("MCLIENT.INI", lpOpenBuffer, OF_EXIST); //Check for file
   
   if (xvalue == HFILE_ERROR)                     //If OpenFile failed
      {
       strcpy(szMessage, MCLIENTINI_OPEN_ERROR);  //Prepare the message with
       _itoa(lpOpenBuffer->nErrCode,szErrorCode,10); //error value returned
       strcat(szMessage, "\nError number: ");        //in OFSTRUCT.nErrCode
       strcat(szMessage, szErrorCode);            //Concatenate the strings
       strcat(szMessage, "\n" RUN_INSTALL);       //Request rerun of Install
       ::MessageBox(NULL, szMessage, APP_TITLE, MB_ICONSTOP);  //Message
       return FALSE;                                          //Abort app
      }
   else                                       //Otherwise OpenFile succeeded
      {
       //Assign the file path
       strcpy(lpszMCIniPath, lpOpenBuffer->szPathName); 
      }
      
   delete lpOpenBuffer;                       //Free the file info buffer
   return TRUE;                               //Return TRUE for file exists
}   
   

//------------------------------------------------------------------------//
// ExitInstance - Overridden function to stop using 3D controls before 
//              exiting this application.
//------------------------------------------------------------------------//
int CApp::ExitInstance()
{
   Ctl3dUnregister (m_hInstance);      //Stop using 3D controls
   
   //
   //Win SDK documention says to call DestroyIcon if you used LoadIcon or 
   //CreateIcon.  That is wrong.  Use DestroyIcon only if you use CreateIcon.
   //DestroyIcon (PortSetIcon);        //Unnecessary call

   if (!TSRLoaded &&                   //Unload MCLIENT.DLL if TSR not loaded
       hinstMClient > HINSTANCE_ERROR) //and handle is valid
      {
       FreeLibrary(hinstMClient); 
      } 

   return FALSE;//CWinApp::ExitInstance ();      //Return ancestor function
}


//========================================================================
// Below we make the application object declaration...                                        
//========================================================================
CApp PortSetApp;
