//========================================================================//
// TSRCALLS.CPP : C++ source code for the functions which call into the   //
//                MCLIENT.EXE TSR. See PORTSETC.DEF for more info.        //
// Remarks     : Compiled under the large memory model.                   //
// History     : 05/28/95 Original version                                //
//                                                                        //
// Written By  : George Cross                                             //
// Copyright (c) Synergy Solutions Inc,1 2150 S Country Club, Mesa, AZ    // 
//========================================================================//

#include "tsrcalls.h"     //Header containing resource identifiers
#include <windows.h>      //Header for Windows SDK declarations
#include <dos.h>          //Header for C library DOS functions
#include <memory.h>       //Header for C library memory functions

//------------------------------------------------------------------------
//
//  FUNCTION: IsLoaded()
//
//  PURPOSE: Used to determine if MCLIENT.EXE or MLCLIENT.EXE is present
//           in memory. Called using Interrupt 14 
//
// INPUT:    AH = 06Fh
//           BX = 0FFFFh (-1)
//           DX = 0FFFFh (-1)
//
// OUTPUT:   DX = Segmentof MA+ communication table
//           BX = Offset of MA+ communication table 
// 
// REMARKS:  If BX is not modified by this call, MCLIENT.EXE nor 
//           MLCLIENT.EXE are present in memory.
//
//------------------------------------------------------------------------

int IsLoaded()
{
 __asm
 {
 
  MOV AH, 06Fh  // AH = 6Fh to test whether MCLIENT.EXE present   
  MOV BX, 0FFFFh  // BX = 0FFFFh (-1)
  MOV DX, 0FFFFh   // ditto for DX
  INT 14h             // call Int 14

  CMP BX, 0FFFFh  // check whether BX was modified
  JZ ISL10           // MCLIENT.EXE is NOT loaded if BX not modified

  MOV CX, BX   // save our offset and, 
  MOV AX, 0002h   // prepare to get selector, set AX = 02h   
  MOV BX, DX          // put segment of MA+ table into BX
  INT 31h             // call Int 31
 
  JC ISL10           // if CF=1, segment invalid, MCLIENT not present
  MOV ES, AX          // move our selector to ES
  MOV DI, CX   // move our offset to DI
  MOV AH, ES:[DI+7]   // move the 7th byte in the MA+ table to AH

  CMP AH, 00h   // if AH is less than zero...
  JL  ISL10           // MCLIENT.EXE is not functioning properly
 }    
       //if((_AH >= '0') || (_AH >= '3'))  // what were you doing here Steve?

  return TRUE;        // MCLIENT.EXE is present 
ISL10:
  return FALSE;  // MCLIENT.EXE is not present

}


//------------------------------------------------------------------------
//
// FUNCTION  :  RMCall()
//
// PURPOSE   :  Retrieve the service names provided by MA+
//
// INPUT     :  Function     - always 16 to retrieve service names
//              Subfunction  - 0 for the first request, 1 for subsequent
//              lpvbufer     - long pointer to the service name buffer
//              Lenbufer     - length of the buffer
//
// OUTPUT    :  return code of the call is in AH
//              0 means a service was found and more are available
//              1 means a service was found and no more are available
//              3 means invalid call
//
//------------------------------------------------------------------------

int RMCall( int Function, int SubFunction, void __far* lpvbufer, int Lenbufer)
{
 typedef struct
 {

  DWORD edi;
  DWORD esi;
  DWORD ebp;
  DWORD ereserved;
  DWORD ebx;
  DWORD edx;
  DWORD ecx;
  DWORD eax;
  WORD flags;
  WORD ees;
  WORD eds;
  WORD efs;
  WORD egs;
  WORD eip;
  WORD ecs;
  WORD esp;
  WORD ess;
 } rmcs;

 rmcs callstruct;
 DWORD rvalue;
 unsigned regBX, regDI;
    void __far* lpvrmcs;

 _fmemset(&callstruct,0,sizeof(rmcs));

  rvalue = GlobalDosAlloc(Lenbufer);
 if(rvalue == NULL)
 return 0xfd;   // couldn't allocate memory

  _fmemcpy(_MK_FP((WORD) rvalue,0),lpvbufer,Lenbufer);

 callstruct.eax = Function * 256;
 callstruct.edx = 0xffff;
 callstruct.ees = (int) (rvalue >> 16);
 callstruct.edi = 0;
 callstruct.ecx = SubFunction;

    lpvrmcs = (void __far*) &callstruct;
    
   regBX = _FP_SEG (lpvrmcs);
 __asm   mov bx, regBX
 __asm mov es,bx
    regDI = _FP_OFF (lpvrmcs);
 __asm   mov di, regDI
 __asm mov ax,0300h
 __asm  mov bl,14h
 __asm  mov bh,0
 __asm  mov cx,0
 __asm int 31h
 
 _fmemcpy(lpvbufer,MK_FP((WORD) rvalue,0),Lenbufer);

 rvalue = GlobalDosFree((WORD) rvalue);
 if(rvalue != NULL)                                                    
  return 0xfe;
 rvalue = ((WORD) callstruct.eax) >> 8;
 return (WORD) rvalue;
}
